==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/BUDGETAMOUNTOPTIONS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYBUDGETEDAMOUNTS" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RESETAMOUNTSTOZERO" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "copybudgetedamounts",
    "resetamountstozero"
})
@XmlRootElement(name = "BUDGETAMOUNTOPTIONS")
public class BUDGETAMOUNTOPTIONS {

    @XmlElement(name = "COPYBUDGETEDAMOUNTS")
    protected String copybudgetedamounts;
    @XmlElement(name = "RESETAMOUNTSTOZERO")
    protected String resetamountstozero;

    /**
     * Obtient la valeur de la propriété copybudgetedamounts.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYBUDGETEDAMOUNTS() {
        return copybudgetedamounts;
    }

    /**
     * Définit la valeur de la propriété copybudgetedamounts.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYBUDGETEDAMOUNTS(String value) {
        this.copybudgetedamounts = value;
    }

    /**
     * Obtient la valeur de la propriété resetamountstozero.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESETAMOUNTSTOZERO() {
        return resetamountstozero;
    }

    /**
     * Définit la valeur de la propriété resetamountstozero.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESETAMOUNTSTOZERO(String value) {
        this.resetamountstozero = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/BUDGETAMOUNTOPTIONS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYBUDGETEDAMOUNTS" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RESETAMOUNTSTOZERO" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "copybudgetedamounts",
    "resetamountstozero"
})
@XmlRootElement(name = "BUDGETAMOUNTOPTIONS")
public class BUDGETAMOUNTOPTIONS {

    @XmlElement(name = "COPYBUDGETEDAMOUNTS")
    protected String copybudgetedamounts;
    @XmlElement(name = "RESETAMOUNTSTOZERO")
    protected String resetamountstozero;

    /**
     * Gets the value of the copybudgetedamounts property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYBUDGETEDAMOUNTS() {
        return copybudgetedamounts;
    }

    /**
     * Sets the value of the copybudgetedamounts property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYBUDGETEDAMOUNTS(String value) {
        this.copybudgetedamounts = value;
    }

    /**
     * Gets the value of the resetamountstozero property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESETAMOUNTSTOZERO() {
        return resetamountstozero;
    }

    /**
     * Sets the value of the resetamountstozero property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESETAMOUNTSTOZERO(String value) {
        this.resetamountstozero = value;
    }

}
